@@ -1,11 +1,11 @@
 ADMINS = (
-    ("loci", "opensource@jensnistler.de"),
+    ("jni", "opensource@jensnistler.de"),
 )
 
 DEBUG = True
 TEMPLATE_DEBUG = DEBUG
 
-SECRET_KEY = "flskf;lsdkflkaw409itc[43umtm9c43u9u*(NYB*(Y89cyptn894"
+SECRET_KEY = "yourSecretKey"
 
 AUTHENTICATION_BACKENDS = (
     "django.contrib.auth.backends.ModelBackend",
@@ -16,11 +16,13 @@ AUTHENTICATION_BACKENDS = (
 
 SOCIAL_AUTH_ENABLED_BACKENDS = ("facebook", "twitter", "github",)
 
-TWITTER_CONSUMER_KEY = "LeEZ6EmnhUDHCPJgCKnJ5A"
-TWITTER_CONSUMER_SECRET = "kpel23moe6wCa8N4WpIgJvDkC4jKXhfZKUmfQYvs71A"
+TWITTER_CONSUMER_KEY = "JsMAzcVPLy3qbV0sBxdgfg"
+TWITTER_CONSUMER_SECRET = "x4LdsxgH0wvbkgXicfez3YL82onWECiYdsztjGIxDI"
 
 GITHUB_APP_ID = "e46d7c062b3158259cd1"
 GITHUB_API_SECRET = "3a8b5f1e09cb0878999fa248bfe3e6a7c4a73539"
 
-FACEBOOK_APP_ID = "299877236703542"
-FACEBOOK_API_SECRET = "9a581e96f686f4ca5b57b378b90d395d"
+FACEBOOK_APP_ID = "325811647445170"
+FACEBOOK_API_SECRET = "1de476311666a65128c9a25e6fd24c9b"
+
+
